# fundamentals

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/fundamentals)](https://pypi.org/project/fundamentals/)  
[![](https://img.shields.io/pypi/v/fundamentals)](https://pypi.org/project/fundamentals/)  
[![](https://img.shields.io/github/license/thespacedoctor/fundamentals)](https://github.com/thespacedoctor/fundamentals)  
[![](https://img.shields.io/pypi/dm/fundamentals)](https://pypi.org/project/fundamentals/)  

<!-- STATUS BADGES -->  

[![](http://167.99.90.204:8080/buildStatus/icon?job=fundamentals%2Fmaster&subject=build%20master)](http://167.99.90.204:8080/blue/organizations/jenkins/fundamentals/activity?branch=master)  
[![](http://167.99.90.204:8080/buildStatus/icon?job=fundamentals%2Fdevelop&subject=build%20dev)](http://167.99.90.204:8080/blue/organizations/jenkins/fundamentals/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/fundamentals@master/coverage.svg)](https://raw.githack.com/thespacedoctor/fundamentals/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/fundamentals/badge/?version=master)](https://fundamentals.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/fundamentals/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/fundamentals/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*Some fundamental tools required by most self-respecting python-packages bundled in one place. Very opinionated project setup tools including logging, plain-text settings files and database connections*.

Documentation for fundamentals is hosted by [Read the Docs](https://fundamentals.readthedocs.io/en/master/) ([development version](https://fundamentals.readthedocs.io/en/develop/) and [master version](https://fundamentals.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/fundamentals). Please report any issues you find [here](https://github.com/thespacedoctor/fundamentals/issues).

## Features

* 



